<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="41"/>
        <source>License</source>
        <translation>ライセンス</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="42"/>
        <location filename="../about.cpp" line="52"/>
        <source>Changelog</source>
        <translation>更新履歴</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="43"/>
        <source>Cancel</source>
        <translation>キャンセル</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="64"/>
        <source>&amp;Close</source>
        <translation>閉じる(&amp;C)</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="47"/>
        <source>GUI for applying assorted useful tweaks</source>
        <translation>色々な設定が行える便利なグラフィカルツール</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="50"/>
        <source>launches brightness-systray</source>
        <translation>明るさ調節トレイアイコンを起動</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="51"/>
        <source>opens with display tab open.  Only valid with Xfce desktop running</source>
        <translation>画面設定タブを開きます。 Xfce デスクトップが動作している場合のみ機能します</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="52"/>
        <source>Opens theme tab directly.  Valid on Xfce &amp; Fluxbox desktops</source>
        <translation>テーマタブを直接開きます。 Xfce と Fluxbox デスクトップでのみ有効です。</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="53"/>
        <source>Opens Other tab directly.  Valid on all desktops</source>
        <translation>他のタブを直接開きます。すべてのデスクトップで有効です</translation>
    </message>
</context>
<context>
    <name>brightness_small</name>
    <message>
        <location filename="../brightness_small.ui" line="14"/>
        <source>MainWindow</source>
        <translation>メインウィンドウ</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="39"/>
        <source>Save</source>
        <translation>保存</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="59"/>
        <source>Software (xrandr) Brightness</source>
        <translation>ソフトウェア（xrandr）の明るさ</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="66"/>
        <location filename="../brightness_small.ui" line="87"/>
        <source>TextLabel</source>
        <translation>テキストラベル</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="80"/>
        <source>Hardware Backlight</source>
        <translation>ハードウェア バックライト</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="94"/>
        <source>&gt;&gt;</source>
        <translation>&gt;&gt;</translation>
    </message>
    <message>
        <location filename="../brightness_small.cpp" line="33"/>
        <source>MX-Tweak</source>
        <translation>MX-Tweak</translation>
    </message>
    <message>
        <location filename="../brightness_small.cpp" line="58"/>
        <source>Display</source>
        <translation>ディスプレイ</translation>
    </message>
    <message>
        <location filename="../brightness_small.cpp" line="63"/>
        <source>&amp;Quit</source>
        <translation>中止(&amp;Q)</translation>
    </message>
</context>
<context>
    <name>defaultlook</name>
    <message>
        <location filename="../defaultlook.ui" line="20"/>
        <location filename="../defaultlook.cpp" line="57"/>
        <location filename="../defaultlook.cpp" line="86"/>
        <location filename="../defaultlook.cpp" line="651"/>
        <location filename="../defaultlook.cpp" line="670"/>
        <location filename="../defaultlook.cpp" line="679"/>
        <location filename="../defaultlook.cpp" line="726"/>
        <location filename="../defaultlook.cpp" line="734"/>
        <location filename="../defaultlook.cpp" line="761"/>
        <location filename="../defaultlook.cpp" line="764"/>
        <source>MX Tweak</source>
        <translation>MX Tweak</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="41"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Customize the panel&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;パネルのカスタマイズ&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="51"/>
        <location filename="../defaultlook.ui" line="272"/>
        <source>Panel</source>
        <translation>パネル</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="71"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Configure window behavior and shortcuts&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;ウィンドウの動作とショートカットの設定&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="85"/>
        <source>Window Manager</source>
        <translation>ウィンドウマネージャ</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="105"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Customize the look of your desktop&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;デスクトップの外観をカスタマイズ&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="119"/>
        <source>Appearance</source>
        <translation>外観</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="133"/>
        <source>Xfce Settings</source>
        <translation>Xfce の設定</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="212"/>
        <source>About</source>
        <translation>情報</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="223"/>
        <source>Help</source>
        <translation>ヘルプ</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="240"/>
        <source>Quit application</source>
        <translation>アプリケーションの終了</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="243"/>
        <source>Close</source>
        <translation>閉じる</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="250"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="283"/>
        <source>Display panel horizontally</source>
        <extracomment>panel will be shown in a horizontal configuration</extracomment>
        <translation>パネルを水平方向に表示</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="293"/>
        <source>Volume</source>
        <extracomment>volume plugin scale factor</extracomment>
        <translation>ボリューム名</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="300"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Docklike&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <extracomment>affects the docklike plugin</extracomment>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;ドックライク&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="307"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Affects all panels&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;すべてのパネルに反映されます&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="327"/>
        <location filename="../defaultlook.ui" line="1725"/>
        <source>Bottom</source>
        <translation>下</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="332"/>
        <location filename="../defaultlook.ui" line="1735"/>
        <source>Top</source>
        <translation>上</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="340"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:700;&quot;&gt;Tasklist&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:700;&quot;&gt;タスク一覧&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="347"/>
        <source>Display panel vertically</source>
        <extracomment>panel will be shown in a vertical configuration</extracomment>
        <translation>パネルを垂直方向に表示</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="362"/>
        <location filename="../defaultlook.ui" line="1753"/>
        <source>Affects 1st panel</source>
        <extracomment>acts on the first poanel found in Xfce panel xml fle</extracomment>
        <translation>第1のパネルに影響します</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="369"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:700;&quot;&gt;Panel Plugin Scales&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:700;&quot;&gt;パネルプラグインのスケール&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="389"/>
        <source>Backup current panel configuration</source>
        <extracomment>backup existing panel configuration</extracomment>
        <translation>現在のパネルの設定をバックアップ</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="399"/>
        <location filename="../defaultlook.ui" line="459"/>
        <source>Options</source>
        <translation>オプション</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="419"/>
        <source>Power Manager</source>
        <extracomment>power manager plugin scale factor</extracomment>
        <translation>電源管理</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="426"/>
        <source>Restore backup panel configuration</source>
        <extracomment>restore a panel backup</extracomment>
        <translation>バックアップしたパネル設定を復旧</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="449"/>
        <source>Set Scales</source>
        <extracomment>set a scale factor</extracomment>
        <translation>スケールの設定</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="479"/>
        <location filename="../defaultlook.ui" line="1730"/>
        <source>Left</source>
        <translation>左</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="484"/>
        <location filename="../defaultlook.ui" line="1740"/>
        <source>Right</source>
        <translation>右</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="492"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Window Buttons&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <extracomment>affects the window button plugin</extracomment>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;ウィンドウボタン&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="513"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Docklike is the modern dock plugin for the panel.  Window Buttons is the classic tasklist without dock features.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Docklike は、パネル用のモダンなドックプラグインです。ウィンドウのボタンは、ドック機能のないクラシックなタスク一覧です。&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="536"/>
        <location filename="../defaultlook.ui" line="630"/>
        <location filename="../defaultlook.ui" line="889"/>
        <location filename="../defaultlook.ui" line="1057"/>
        <location filename="../defaultlook.ui" line="1064"/>
        <location filename="../defaultlook.ui" line="1071"/>
        <location filename="../defaultlook.ui" line="1138"/>
        <location filename="../defaultlook.ui" line="1283"/>
        <location filename="../defaultlook.ui" line="1766"/>
        <location filename="../defaultlook.ui" line="1890"/>
        <source>Apply</source>
        <translation>適用</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="556"/>
        <source>Restore default panel</source>
        <extracomment>affects any panel that is curently configured</extracomment>
        <translation>既定のパネルを復旧</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="566"/>
        <source>Set Tasklist plugin to:</source>
        <extracomment>change the tasklist plugin</extracomment>
        <translation>タスク一覧のリストプラグインを設定：</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="580"/>
        <source>Theme</source>
        <translation>テーマ</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="596"/>
        <source>Theme Options</source>
        <translation>テーマのオプション</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="606"/>
        <source>Remove User Theme Set</source>
        <translation>ユーザーのテーマセット削除</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="617"/>
        <source>Preview</source>
        <translation>プレビュー</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="656"/>
        <source>Undo</source>
        <translation>元に戻す</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="666"/>
        <source>Save Current Settings as a Theme Set</source>
        <extracomment>save theme settings as a group</extracomment>
        <translation>現在の設定をテーマセットとして保存</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="687"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Cursors&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <extracomment>cursor theme</extracomment>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;カーソル&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="694"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Window Manager&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <extracomment>theme a window manager border will get</extracomment>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;ウィンドウマネージャ&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="704"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Application&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <extracomment>theme an application will get</extracomment>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;アプリケーション&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="711"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Icons&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <extracomment>icon theme</extracomment>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;アイコン&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="728"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:12pt; font-weight:600;&quot;&gt;Themes&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:12pt; font-weight:600;&quot;&gt;テーマ&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="738"/>
        <location filename="../defaultlook.ui" line="756"/>
        <source>Compositor</source>
        <translation>コンポジタ</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="749"/>
        <source>Transparency and shadow options</source>
        <translation>透明度と影に関するオプション</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="763"/>
        <source>Edit compton.conf directly in text editor</source>
        <translation>コンプトンの設定ファイルを直接テキストエディタで編集</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="766"/>
        <source>Edit compton.conf</source>
        <translation>コンプトンの設定ファイルを編集</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="777"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Xfce Compositor Settings&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Xfce コンポジタの設定&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="780"/>
        <source>Xfwm Settings</source>
        <translation>Xfwm の設定</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="791"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Changing the VBlank mode may help alleviate some screen tearing issues.  See Help for more information.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;VBlank モードを変更すると、画面分割の問題が軽減される場合があります。 詳細については、ヘルプを参照してください。&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="794"/>
        <source>VBlank</source>
        <translation>VBlank</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="801"/>
        <source>Launch compton-conf configuration tool</source>
        <translation>コンプトン設定ツールを起動</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="804"/>
        <source>Compton settings</source>
        <translation>コンプトンの設定</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="828"/>
        <source>None</source>
        <translation>なし</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="833"/>
        <source>Xfwm (Xfce) Compositor</source>
        <translation>Xfwm (Xfce) コンポジタ</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="838"/>
        <source>Compton </source>
        <translation>コンプトン</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="847"/>
        <source>auto</source>
        <translation>自動</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="852"/>
        <source>glx</source>
        <translation>glx</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="857"/>
        <source>xpresent</source>
        <translation>Xresent</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="862"/>
        <location filename="../defaultlook.ui" line="1396"/>
        <source>off</source>
        <extracomment>setting to 0 turns off screensaver screen blank</extracomment>
        <translation>オフ</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="912"/>
        <source>Display</source>
        <translation>ディスプレイ</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="923"/>
        <source>Hardware Backlight</source>
        <extracomment>set the hardware backlight on monitors that have them</extracomment>
        <translation>ハードウェアのバックライト</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="930"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Display Tweaks&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;ディスプレイの Tweak&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="957"/>
        <source>Choose Display for xrandr tweaks</source>
        <extracomment>choose the display that the xrandr tweaks will be acted upon</extracomment>
        <translation>ディスプレイの XRandR tweak を選択</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="967"/>
        <source>Resolution</source>
        <translation>解像度</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="974"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Saving is per display&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;ディスプレイ毎に保存&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="977"/>
        <source>Save</source>
        <translation>保存</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="984"/>
        <source>Software (xrandr) Brightness</source>
        <extracomment>adjust brightness (not backlight) via software</extracomment>
        <translation>ソフトウェア（XRandR）の明るさ</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="991"/>
        <location filename="../defaultlook.ui" line="1088"/>
        <source>TextLabel</source>
        <translation>テキストラベル</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="998"/>
        <source>GTK scaling</source>
        <extracomment>gtk scale factor</extracomment>
        <translation>GTK のスケーリング</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1018"/>
        <source>xrandr Scaling</source>
        <extracomment>xrandr scale factor</extracomment>
        <translation>XRandR スケーリング</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1114"/>
        <source>Config Options</source>
        <translation>オプションの設定</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1125"/>
        <source>Disable shortening of long filenames on the desktop</source>
        <translation>デスクトップでの長いファイル名の短縮を無効化</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1149"/>
        <source>                   note: to hibernate, swap needs to be &gt;= RAM</source>
        <translation>注意: ハイバネートするには、スワップが &gt;= RAM である必要があります</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1169"/>
        <source>Enable single-click on desktop</source>
        <translation>デスクトップでシングルクリックを有効化</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1176"/>
        <source>Enable hibernate on Log Out menu </source>
        <translation>ログアウトメニューでハイバネートを有効化</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1183"/>
        <location filename="../defaultlook.ui" line="1317"/>
        <source>Reset Thunar custom right-click actions to system defaults</source>
        <translation>Thunar のカスタム右クリックアクションをシステムの既定にリセット</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1190"/>
        <location filename="../defaultlook.ui" line="1368"/>
        <source>Enable single-click in Thunar File Manager</source>
        <translation>Thunar ファイルマネージャでシングルクリックを有効化</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1197"/>
        <location filename="../defaultlook.ui" line="1629"/>
        <source>Thunar windows always open in split view</source>
        <translation>Thunar ウィンドウが常にスプリットビューで開く</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1204"/>
        <location filename="../defaultlook.ui" line="1561"/>
        <source>Thunar split view opens horizontal</source>
        <translation>Thunar スプリットビューが水平方向に開く</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1211"/>
        <source>Show percentages in notifcations when available</source>
        <translation>可能なときは通知でパーセンテージを表示する</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1218"/>
        <source>Enable Desktop Zoom </source>
        <translation>デスクトップズームの有効化</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1225"/>
        <location filename="../defaultlook.ui" line="1815"/>
        <source>Show windows from all workspaces in panel</source>
        <translation>パネルに全てのワークスペースのウィンドウを表示</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1232"/>
        <source>Show GTK File Dialog action buttons at bottom of dialogs</source>
        <translation>GTK ファイルダイアログのアクションボタンをダイアログ下部に表示</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1239"/>
        <source>( also turns off Client Side Decorations for Xfce applications)</source>
        <translation>( また、Xfce アプリケーションのクライアント側の修飾をオフにします。)</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1252"/>
        <source>Fluxbox</source>
        <translation>Fluxbox</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1389"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Dock Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;ドックの設定&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1690"/>
        <source>Idle time (minutes)</source>
        <extracomment>set the time of inactivity  before screensaver screen blank occurs</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1264"/>
        <location filename="../defaultlook.ui" line="1604"/>
        <source>On</source>
        <translation>オン</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1269"/>
        <location filename="../defaultlook.ui" line="1609"/>
        <source>Off</source>
        <translation>オフ</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1568"/>
        <source>Manage Tint2 Panel</source>
        <translation>Tint2 パネルの管理</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1579"/>
        <source>Height</source>
        <translation>高さ</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1382"/>
        <location filename="../defaultlook.ui" line="1406"/>
        <source>Autohide</source>
        <translation>自動的に隠す</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1586"/>
        <location filename="../defaultlook.ui" line="1622"/>
        <location filename="../defaultlook.ui" line="1714"/>
        <source>Placement</source>
        <translation>配置</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1290"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Thunar&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Thunar&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1480"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Desktop Icons&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;デスクトップのアイコン&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1337"/>
        <source>Toggle icon captions</source>
        <translation>アイコンのキャプションを切り替え</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1614"/>
        <source>On Hover</source>
        <translation>停止</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1375"/>
        <source>Toggle desktop icons</source>
        <translation>デスクトップのアイコンを切り替えます</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1636"/>
        <location filename="../defaultlook.ui" line="1829"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Reset Defaults&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;初期設定に戻す&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1297"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Toolbar Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;ツールバーの設定&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1361"/>
        <source>Width</source>
        <translation>横幅</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1593"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:700;&quot;&gt;Screensaver&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <extracomment>screensaver screen blank settings</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1666"/>
        <source>Show Toolbar</source>
        <translation>ツールバーを表示</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1554"/>
        <source>Reset DefaultDock</source>
        <translation>標準ドックをリセット</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1344"/>
        <source>Reset Fluxbox Menu</source>
        <translation>Fluxbox メニューをリセット</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1683"/>
        <source>Reset ALL mx-fluxbox settings</source>
        <translation>mx-fluxbox の設定をすべてリセットします</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1643"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Add new default menu items, if any, to existing fluxbox menu.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;新しい既定メニュー項目があれば、既存の fluxbox メニューに追加します。&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1646"/>
        <source>Upgrade existing menu entries</source>
        <translation>既存のメニューエントリをアップグレード</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1703"/>
        <source>Plasma</source>
        <translation>プラズマ</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1782"/>
        <source>Workspace</source>
        <translation>ワークスペース</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1822"/>
        <source>Enable single-click</source>
        <translation>シングルクリックを有効にします</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1836"/>
        <source>Reset KDE/Plasma defaults</source>
        <translation>KDE/プラズマ の設定を元に戻します</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1846"/>
        <source>Other</source>
        <translation>その他</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1870"/>
        <source>Reset Lightdm (login screen) to system default theme</source>
        <translation>Lightdm（ログイン画面）をシステムの既定テーマにリセット</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1877"/>
        <source>Password for administrative tasks:</source>
        <translation>管理業務用のパスワード：</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1908"/>
        <source>Enable mounting of internal drives by non-root users</source>
        <translation>非 root ユーザーによる内蔵ドライブのマウントを可能にする</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1915"/>
        <source>Root</source>
        <translation>Root</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1922"/>
        <source>Enable kernel sandbox</source>
        <translation>カーネルサンドボックスの有効化</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1929"/>
        <source>&amp;User</source>
        <translation>ユーザー(&amp;U)</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1936"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;requires reboot&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;再起動が必要です&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1939"/>
        <source>Enable Bluetooth Adapters on boot</source>
        <translation>起動時に Bluetooth アダプタを有効にします</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1946"/>
        <source>Apt installs additional &quot;recommends&quot; packages as dependencies</source>
        <translation>APT は推奨パッケージを依存関係にあるものとして追加します</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1953"/>
        <source>Generate fluxbox All Apps menu after package installation, removal, and updates</source>
        <translation>パッケージのインストール／削除／更新後に fluxbox の「すべてのアプリ」メニューを生成する</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1960"/>
        <source>Use Client Side Decorations (CSD) on GTK3 applications that support them (requires session restart)</source>
        <translation>GTK3 をサポートするアプリケーションでクライアント側装飾 (CSD) をを使用します (セッションの再起動が必要です)</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1967"/>
        <source>Use intel driver instead of default &quot;modesetting&quot; driver (requires restart)</source>
        <translation>既定の &quot;modesetting&quot; ドライバの替わりに intel ドライバを使用 (再起動が必要)</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1974"/>
        <source>          NOTE: existing /etc/X11/xorg.conf.d/20-intel.conf will be backed up to home folder</source>
        <translation>注意: 既存の /etc/X11/xorg.conf.d/20-intel.conf はホームフォルダにバックアップされます</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1981"/>
        <source>Use tearfree amdgpu option</source>
        <translation>TearFree amdgpu オプションを使用</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1988"/>
        <source>          NOTE: existing /etc/X11/xorg.conf.d/20-amd.conf will be backed up to home folder</source>
        <translation>注意: 既存の /etc/X11/xorg.conf.d/20-amd.conf はホームフォルダにバックアップされます。</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1995"/>
        <source>Use tearfree radeon driver option</source>
        <translation>TearFree radeon ドライバのオプションを使用</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="2002"/>
        <source>          NOTE: existing /etc/X11/xorg.conf.d/20-radeon.conf will be backed up to home folder</source>
        <translation>注意: 既存の /etc/X11/xorg.conf.d/20-radeon.conf はホームフォルダにバックアップされます</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="58"/>
        <source>--display switch only valid for Xfce</source>
        <translation>--Xfce専用のスイッチを表示</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="650"/>
        <source>About MX Tweak</source>
        <translation>MX Tweak について</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="652"/>
        <source>Version: </source>
        <translation>バージョン: </translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="653"/>
        <source>App for quick default ui theme changes and tweaks</source>
        <translation>既定の UI テーマの変更や調整を素早く行えるアプリ</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="655"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="656"/>
        <source>%1 License</source>
        <translation>%1 ライセンス</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="670"/>
        <source>%1 Help</source>
        <translation>%1 ヘルプ</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="680"/>
        <source>Finished! Firefox may require a restart for changes to take effect</source>
        <translation>完了しました！ Firefox では変更を有効にするため再起動が必要な場合があります</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="727"/>
        <source>Plese remove special characters</source>
        <translation>特殊文字を削除してください</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="727"/>
        <source>from file name</source>
        <translation>ファイル名より</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="734"/>
        <source>File name already exists.  Choose another name</source>
        <translation>そのファイル名は既に存在します。別の名前を選んでください。</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="762"/>
        <source>File is not a valid tar.xz archive file</source>
        <translation>そのファイルは無効な tar.xz 形式です</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="765"/>
        <source>Archive does not contain a panel config</source>
        <translation>書庫にはパネルの設定を含んでいません</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="940"/>
        <source>Panel settings</source>
        <translation>パネルの設定</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="941"/>
        <source>Your current panel settings have been backed up in a hidden folder called .restore in your home folder (~/.restore/)</source>
        <translation>現在のパネル設定は、ホームフォルダ (~/) 以下にある .restore という隠しフォルダにバックアップされました</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="1723"/>
        <source>settings</source>
        <translation>設定</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="2063"/>
        <source>Choose a theme set</source>
        <translation>テーマセットを選択</translation>
    </message>
</context>
<context>
    <name>remove_user_theme_set</name>
    <message>
        <location filename="../remove_user_theme_set.ui" line="14"/>
        <source>Remove User Theme Set</source>
        <translation>ユーザーのテーマセットを削除</translation>
    </message>
</context>
<context>
    <name>theming_to_tweak</name>
    <message>
        <location filename="../theming_to_tweak.ui" line="14"/>
        <source>New Theme Set</source>
        <translation>新しいテーマセット</translation>
    </message>
    <message>
        <location filename="../theming_to_tweak.ui" line="20"/>
        <source>Enter name for new theme set</source>
        <translation>新しいテーマセットの名前を入力</translation>
    </message>
</context>
<context>
    <name>window_buttons</name>
    <message>
        <location filename="../window_buttons.ui" line="14"/>
        <location filename="../window_buttons.cpp" line="24"/>
        <source>Window Buttons</source>
        <translation>ウィンドウボタン</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="28"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Appearance&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;外観&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="35"/>
        <source>Show button labels</source>
        <translation>ボタンラベルを表示する</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="42"/>
        <source>Show flat buttons</source>
        <translation>フラットボタンで表示する</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="49"/>
        <source>Show handle</source>
        <translation>取っ手を表示する</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="56"/>
        <source>Sorting Order:</source>
        <translation>並び替え順:</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="64"/>
        <source>Timestamp</source>
        <translation>タイムスタンプ</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="69"/>
        <source>Group title and timestamp</source>
        <translation>グループタイトルとタイムスタンプ</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="74"/>
        <source>Window Title</source>
        <translation>ウィンドウタイトル</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="79"/>
        <source>Group title and window title</source>
        <translation>グループタイトルとウィンドウタイトル</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="84"/>
        <source>None, allow drag-and-drop</source>
        <translation>なし、ドラッグアンドドロップを許可</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="92"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Behavior&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;振る舞い&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="99"/>
        <source>Window grouping:</source>
        <translation>ウィンドウのグループ化:</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="107"/>
        <source>Never</source>
        <translation>しない</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="112"/>
        <source>Always</source>
        <translation>常時</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="120"/>
        <source>Middle click action:</source>
        <translation>中クリック時の動作:</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="128"/>
        <source>Nothing</source>
        <translation>何もしない</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="133"/>
        <source>Close window</source>
        <translation>ウィンドウを閉じる</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="138"/>
        <source>Minimize window</source>
        <translation>最小化</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="146"/>
        <source>Restore minimized windows to current workspace</source>
        <translation>最小化されたウィンドウを現在のワークスペースで元に戻す</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="153"/>
        <source>Draw window frame when hovering over a button</source>
        <translation>ポインターがボタン上にあるときにウィンドウ枠を描画する</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="160"/>
        <source>Switch windows using the mouse wheel</source>
        <translation>マウスホイールを使用してウィンドウを切り替える</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="167"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Filtering&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;フィルタリング&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="174"/>
        <source>Show windows from all workspaces or viewports</source>
        <translation>全ワークスペースまたはビューポートのウィンドウを表示する</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="181"/>
        <source>Show only minimized windows</source>
        <translation>最小化されたウィンドウのみ表示する</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="188"/>
        <source>Show windows from all monitors</source>
        <translation>全モニターのウィンドウを表示する</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="238"/>
        <source>Close</source>
        <translation>閉じる</translation>
    </message>
</context>
<context>
    <name>xfwm_compositor_settings</name>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="14"/>
        <source>Dialog</source>
        <translation>ダイアログ</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="42"/>
        <source>Popup Windows</source>
        <translation>ポップアップウィンドウ</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="49"/>
        <source>Windows during move</source>
        <translation>移動中のウィンドウ</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="56"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Opacity Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;不透過度の設定&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="79"/>
        <source>Window decorations</source>
        <translation>ウィンドウの装飾</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="86"/>
        <source>Show shadows under dock windows</source>
        <translation>ドックウインドウの下に影を表示</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="93"/>
        <source>Show shadows under popup windows</source>
        <translation>ポップアップウィンドウの下に影を表示</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="100"/>
        <source>Windows during resize</source>
        <translation>リサイズ中のウィンドウ</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="123"/>
        <source>Show shadows under regular windows</source>
        <translation>通常のウィンドウで影を表示</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="130"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Feature Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;機能設定&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="137"/>
        <source>Show windows preview in place of icons when cycling</source>
        <translation>サイクリング時にアイコンの代わりにウィンドウのプレビューを表示</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="144"/>
        <source>Display fullscreen overlay windows directly</source>
        <translation>画面全体にオーバーレイウィンドウを直接表示</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="183"/>
        <source>Inactive windows</source>
        <translation>非アクティブなウィンドウ</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="190"/>
        <source>Synchronize drawing to vertical blank</source>
        <translation>垂直ブランクに描画を同期</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="212"/>
        <source>Close</source>
        <translation>閉じる</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.cpp" line="23"/>
        <source>Xfwm Compositor Settings</source>
        <translation>Xfwm コンポジタの設定</translation>
    </message>
</context>
</TS>
